@@ -5,11 +5,9 @@
 ## Description: tied array access to indexed data files
 
 package Tie::File::Indexed;
-use 5.10.0; ##-- for // operator
 use Tie::Array;
 use JSON qw();
 use Fcntl qw(:DEFAULT :seek :flock);
-use File::Copy qw();
 use IO::File;
 use Carp qw(confess);
 use strict;
@@ -18,7 +16,7 @@ use strict;
 ## Globals
 
 our @ISA     = qw(Tie::Array);
-our $VERSION = '0.05_001';
+our $VERSION = 0.01;
 
 ##======================================================================
 ## Constructors etc.
@@ -30,10 +28,9 @@ our $VERSION = '0.05_001';
 ##     file   => $file,    ##-- file basename; uses files "${file}", "${file}.idx", "${file}.hdr"
 ##     mode   => $mode,    ##-- open mode (fcntl flags or perl-style; default='rwa')
 ##     perms  => $perms,   ##-- default: 0666 & ~umask
-##     pack_o => $pack_o,  ##-- file offset pack template (default='J')
-##     pack_l => $pack_l,  ##-- string-length pack template (default='J')
+##     pack_o => $pack_o,  ##-- file offset pack template (default='N')
+##     pack_l => $pack_l,  ##-- string-length pack template (default='N')
 ##     bsize  => $bsize,   ##-- block-size in bytes for index batch-operations (default=2**21 = 2MB)
-##     temp   => $bool,    ##-- if true, call unlink() on object destruction (default=false)
 ##     ##
 ##     ##-- pack lengths (after open())
 ##     len_o  => $len_o,   ##-- packsize($pack_o)
@@ -66,17 +63,15 @@ sub defaults {
 	  #file  => $file,
 	  perms  => (0666 & ~umask),
 	  mode   => 'rwa',
-	  pack_o => 'J',
-	  pack_l => 'J',
+	  pack_o => 'N',
+	  pack_l => 'N',
 	  block  => 2**21,
 	 );
 }
 
 ## undef = $tied->DESTROY()
-##  + implicitly calls unlink() if 'temp' attribute is set to a true value
 ##  + implicitly calls close()
 sub DESTROY {
-  $_[0]->unlink() if ($_[0]{temp});
   $_[0]->close();
 }
 
@@ -495,9 +490,6 @@ sub flush {
     : undef;
 }
 
-##--------------------------------------------------------------
-## Object API: file operations
-
 ## $tied_or_undef = $tied->unlink()
 ## $tied_or_undef = $tied->unlink($file)
 ##  + attempts to unlink underlying files
@@ -506,64 +498,12 @@ sub unlink {
   my ($tied,$file) = @_;
   $file //= $tied->{file};
   $tied->close();
-  return undef if (!defined($file));
   foreach ('','.idx','.hdr') {
     CORE::unlink("${file}$_") or return undef;
   }
   return $tied;
 }
 
-## $tied_or_undef = $tied->rename($newname)
-##  + renames underlying file(s) using CORE::rename()
-##  + implicitly close()s and re-open()s $tied
-##  + object must be opened in write-mode
-sub rename {
-  my ($tied,$newfile) = @_;
-  my $flags   = fcflags($tied->{mode});
-  my $oldfile = $tied->{file};
-  return undef if (!$tied->opened() || !fcwrite($flags) || !$tied->close);
-  foreach ('','.idx','.hdr') {
-    CORE::rename("${oldfile}$_","${newfile}$_") or return undef;
-  }
-  return $tied->open($newfile, ($flags & ~O_TRUNC));
-}
-
-## $dst_object_or_undef = $tied_src->copy($dst_filename, %dst_opts)
-## $dst_object_or_undef = $tied_src->copy($dst_object)
-##  + copies underlying file(s) using File::Copy::copy()
-##  + source object must be opened
-##  + implicitly calls flush() on both source and destination objects
-##  + if a destination object is specified, it must be opened in write-mode
-sub copy {
-  my ($src,$dst,%opts) = @_;
-  return undef if (!$src->opened || !$src->flush);
-  $dst = $src->new($dst, %opts, mode=>'rw') if (!ref($dst));
-  return undef if (!$dst->opened && !$dst->open($opts{file}, 'rw'));
-
-  foreach (qw(idxfh datfh)) {
-    CORE::seek($src->{$_}, 0, SEEK_SET) or return undef;
-    CORE::seek($dst->{$_}, 0, SEEK_SET) or return undef;
-    File::Copy::copy($src->{$_}, $dst->{$_}) or return undef;
-  }
-  return $dst->flush();
-}
-
-## $tied_or_undef = $tied->move($newname)
-##  + renames underlying file(s) using File::Copy::move()
-##  + implicitly close()s and re-open()s $tied
-##  + object must be opened in write-mode
-sub move {
-  my ($tied,$newfile) = @_;
-  my $flags   = fcflags($tied->{mode});
-  my $oldfile = $tied->{file};
-  return undef if (!$tied->opened() || !fcwrite($flags) || !$tied->close);
-  foreach ('','.idx','.hdr') {
-    File::Copy::move("${oldfile}$_","${newfile}$_") or return undef;
-  }
-  return $tied->open($newfile, ($flags & ~O_TRUNC));
-}
-
-
 
 ##--------------------------------------------------------------
 ## Object API: consolidate
@@ -583,7 +523,7 @@ sub consolidate {
   binmode($tmpfh);
 
   ##-- copy data
-  my ($file,$idxfh,$datfh,$len_ix,$pack_ix) = @$tied{qw(file idxfh datfh len_ix pack_ix)};
+  my ($idxfh,$datfh,$len_ix,$pack_ix) = @$tied{qw(idxfh datfh len_ix pack_ix)};
   my ($buf,$off,$len);
   my $size = $tied->size;
   CORE::seek($idxfh, 0, SEEK_SET) or return undef;
@@ -603,25 +543,14 @@ sub consolidate {
     $tmpfh->print($buf) or return undef;
   }
 
-  ##-- close data-filehandles
-  CORE::close($tmpfh)
-      or confess(ref($tied)."::consolidate(): failed to close temp-file '$tmpfile': $!");
-  CORE::close($datfh)
-    or confess(ref($tied)."::consolidate(): failed to close old data-file '$file': $!");
-
-  ##-- replace old datafile
-  undef $tmpfh;
-  undef $datfh;
+  ##-- swap data filehandle
+  undef  $datfh;
   delete $tied->{datfh};
-  CORE::unlink($file)
+  CORE::unlink($tied->{file})
       or confess(ref($tied)."::consolidate(): failed to unlink old data-file '$tied->{file}': $!");
-  #CORE::rename($tmpfile, $file) ##-- win32 chokes here with "Permission denied"
-  File::Copy::move($tmpfile, $file)
-      or confess(ref($tied)."::consolidate(): failed to move temp-file '$tmpfile' to '$file': $!");
-
-  ##-- re-open
-  $tied->{datfh} = fcopen("$file", (fcflags($tied->{mode}) & ~O_TRUNC), $tied->{perms})
-    or confess(ref($tied)."::consolidate(): failed to re-open data-file $file: $!");
+  CORE::rename($tmpfile, $tied->{file})
+      or confess(ref($tied)."::consolidate(): failed to rename temp-file '$tmpfile' to '$tied->{file}': $!");
+  $tied->{datfh} = $tmpfh;
 
   return $tied;
 }
